@@ -701,7 +701,9 @@ def _import_from_importer(network, importer, basename, skip_time=False):
 
     ##https://docs.python.org/3/tutorial/datastructures.html#comparing-sequences-and-other-types
     if pypsa_version is None or pypsa_version < current_pypsa_version:
-        pypsa_version_str = ".".join(map(str, pypsa_version))
+        pypsa_version_str = (
+            ".".join(map(str, pypsa_version)) if pypsa_version is not None else "?"
+        )
         current_pypsa_version_str = ".".join(map(str, current_pypsa_version))
         msg = (
             f"Importing network from PyPSA version v{pypsa_version_str} while "
@@ -722,7 +724,9 @@ def _import_from_importer(network, importer, basename, skip_time=False):
 
     if df is not None:
         # check if imported snapshots have MultiIndex
-        snapshot_levels = set(["period", "timestep"]).intersection(df.columns)
+        snapshot_levels = set(["period", "timestep", "snapshot"]).intersection(
+            df.columns
+        )
         if snapshot_levels:
             df.set_index(sorted(snapshot_levels), inplace=True)
         network.set_snapshots(df.index)
