@@ -86,7 +86,7 @@ def aggregategenerators(
     strategies = {
         "p_nom_max": pd.Series.min,
         "weight": pd.Series.sum,
-        "p_nom": pd.Series.min,
+        "p_nom": pd.Series.sum,
         "capital_cost": pd.Series.sum,
         "efficiency": pd.Series.mean,
         "ramp_limit_up": pd.Series.mean,
@@ -175,10 +175,23 @@ def aggregateoneport(
     new_df.index = _flatten_multiindex(new_df.index).rename("name")
 
     new_pnl = dict()
+
+    def normed_or_uniform(x):
+        return (
+            x / x.sum() if x.sum(skipna=False) > 0 else pd.Series(1.0 / len(x), x.index)
+        )
+
+    if "e_nom" in new_df.columns:
+        weighting = old_df.e_nom.groupby(grouper, axis=0).transform(normed_or_uniform)
+    elif "p_nom" in new_df.columns:
+        weighting = old_df.p_nom.groupby(grouper, axis=0).transform(normed_or_uniform)
+
     if with_time:
         old_pnl = network.pnl(component)
         for attr, df in old_pnl.items():
             if not df.empty:
+                if attr in ["e_min_pu", "e_max_pu", "p_min_pu", "p_max_pu"]:
+                    df = df.multiply(weighting.loc[df.columns], axis=1)
                 pnl_df = df.groupby(grouper, axis=1).sum()
                 pnl_df.columns = _flatten_multiindex(pnl_df.columns).rename("name")
                 new_pnl[attr] = pnl_df
@@ -217,7 +230,6 @@ def aggregatebuses(network, busmap, custom_strategies=dict()):
 
 
 def aggregatelines(network, buses, interlines, line_length_factor=1.0, with_time=True):
-
     # make sure all lines have same bus ordering
     positive_order = interlines.bus0_s < interlines.bus1_s
     interlines_p = interlines[positive_order]
